@@ -111,6 +111,13 @@ class Application extends Container
      */
     public $router;
 
+    /**
+     * The array of terminating callbacks.
+     *
+     * @var callable[]
+     */
+    protected $terminatingCallbacks = [];
+
     /**
      * Create a new Lumen application instance.
      *
@@ -162,7 +169,7 @@ class Application extends Container
      */
     public function version()
     {
-        return 'Lumen (8.3.4) (Laravel Components ^8.0)';
+        return 'Lumen (10.0.4) (Laravel Components ^10.0)';
     }
 
     /**
@@ -200,6 +207,26 @@ class Application extends Container
         return $env;
     }
 
+    /**
+     * Determine if the application is in the local environment.
+     *
+     * @return bool
+     */
+    public function isLocal()
+    {
+        return $this->environment() === 'local';
+    }
+
+    /**
+     * Determine if the application is in the production environment.
+     *
+     * @return bool
+     */
+    public function isProduction()
+    {
+        return $this->environment() === 'production';
+    }
+
     /**
      * Determine if the given service provider is loaded.
      *
@@ -763,7 +790,9 @@ class Application extends Container
             $merged = array_merge($defaults, $userAliases);
 
             foreach ($merged as $original => $alias) {
-                class_alias($original, $alias);
+                if (! class_exists($alias)) {
+                    class_alias($original, $alias);
+                }
             }
         }
     }
@@ -791,10 +820,10 @@ class Application extends Container
     /**
      * Get the base path for the application.
      *
-     * @param  string|null  $path
+     * @param  string  $path
      * @return string
      */
-    public function basePath($path = null)
+    public function basePath($path = '')
     {
         if (isset($this->basePath)) {
             return $this->basePath.($path ? '/'.$path : $path);
@@ -831,6 +860,17 @@ class Application extends Container
         return $this->basePath.DIRECTORY_SEPARATOR.'database'.($path ? DIRECTORY_SEPARATOR.$path : $path);
     }
 
+    /**
+     * Get the path to the language files.
+     *
+     * @param  string  $path
+     * @return string
+     */
+    public function langPath($path = '')
+    {
+        return $this->getLanguagePath().($path != '' ? DIRECTORY_SEPARATOR.$path : '');
+    }
+
     /**
      * Get the storage path for the application.
      *
@@ -895,7 +935,7 @@ class Application extends Container
      */
     public function runningUnitTests()
     {
-        return $this->environment() == 'testing';
+        return $this->environment() === 'testing';
     }
 
     /**
@@ -966,6 +1006,7 @@ class Application extends Container
         $this->router = null;
         $this->dispatcher = null;
         static::$instance = null;
+        static::$aliasesRegistered = false;
     }
 
     /**
@@ -978,6 +1019,16 @@ class Application extends Container
         return $this['config']->get('app.locale');
     }
 
+    /**
+     * Get the current application fallback locale.
+     *
+     * @return string
+     */
+    public function getFallbackLocale()
+    {
+        return $this['config']->get('app.fallback_locale');
+    }
+
     /**
      * Set the current application locale.
      *
@@ -1001,6 +1052,35 @@ class Application extends Container
         return $this->getLocale() == $locale;
     }
 
+    /**
+     * Register a terminating callback with the application.
+     *
+     * @param  callable|string  $callback
+     * @return $this
+     */
+    public function terminating($callback)
+    {
+        $this->terminatingCallbacks[] = $callback;
+
+        return $this;
+    }
+
+    /**
+     * Terminate the application.
+     *
+     * @return void
+     */
+    public function terminate()
+    {
+        $index = 0;
+
+        while ($index < count($this->terminatingCallbacks)) {
+            $this->call($this->terminatingCallbacks[$index]);
+
+            $index++;
+        }
+    }
+
     /**
      * Register the core container aliases.
      *
