@@ -3,14 +3,21 @@
 namespace Laravel\Lumen\Console;
 
 use Illuminate\Console\Application as Artisan;
+use Illuminate\Console\Events\CommandFinished;
+use Illuminate\Console\Events\CommandStarting;
 use Illuminate\Console\Scheduling\Schedule;
 use Illuminate\Console\Scheduling\ScheduleRunCommand;
 use Illuminate\Contracts\Console\Kernel as KernelContract;
 use Illuminate\Contracts\Debug\ExceptionHandler;
+use Illuminate\Contracts\Events\Dispatcher;
 use Illuminate\Http\Request;
 use Laravel\Lumen\Application;
 use Laravel\Lumen\Exceptions\Handler;
 use RuntimeException;
+use Symfony\Component\Console\ConsoleEvents;
+use Symfony\Component\Console\Event\ConsoleCommandEvent;
+use Symfony\Component\Console\Event\ConsoleTerminateEvent;
+use Symfony\Component\EventDispatcher\EventDispatcher;
 use Throwable;
 
 class Kernel implements KernelContract
@@ -22,6 +29,13 @@ class Kernel implements KernelContract
      */
     protected $app;
 
+    /**
+     * The Symfony event dispatcher implementation.
+     *
+     * @var \Symfony\Contracts\EventDispatcher\EventDispatcherInterface|null
+     */
+    protected $symfonyDispatcher;
+
     /**
      * The Artisan application instance.
      *
@@ -55,6 +69,8 @@ class Kernel implements KernelContract
 
         if ($this->app->runningInConsole()) {
             $this->setRequestForConsole($this->app);
+        } else {
+            $this->rerouteSymfonyCommandEvents();
         }
 
         $this->app->prepareForConsoleCommand($this->aliases);
@@ -87,6 +103,34 @@ class Kernel implements KernelContract
         ));
     }
 
+    /**
+     * Re-route the Symfony command events to their Laravel counterparts.
+     *
+     * @internal
+     *
+     * @return $this
+     */
+    public function rerouteSymfonyCommandEvents()
+    {
+        if (is_null($this->symfonyDispatcher)) {
+            $this->symfonyDispatcher = new EventDispatcher;
+
+            $this->symfonyDispatcher->addListener(ConsoleEvents::COMMAND, function (ConsoleCommandEvent $event) {
+                $this->app[Dispatcher::class]->dispatch(
+                    new CommandStarting($event->getCommand()->getName(), $event->getInput(), $event->getOutput())
+                );
+            });
+
+            $this->symfonyDispatcher->addListener(ConsoleEvents::TERMINATE, function (ConsoleTerminateEvent $event) {
+                $this->app[Dispatcher::class]->dispatch(
+                    new CommandFinished($event->getCommand()->getName(), $event->getInput(), $event->getOutput(), $event->getExitCode())
+                );
+            });
+        }
+
+        return $this;
+    }
+
     /**
      * Define the application's command schedule.
      *
@@ -113,14 +157,18 @@ class Kernel implements KernelContract
         try {
             $this->app->boot();
 
-            return $this->getArtisan()->run($input, $output);
+            $status = $this->getArtisan()->run($input, $output);
         } catch (Throwable $e) {
             $this->reportException($e);
 
             $this->renderException($output, $e);
 
-            return 1;
+            $status = 1;
         }
+
+        $this->terminate($input, $status);
+
+        return $status;
     }
 
     /**
@@ -142,7 +190,7 @@ class Kernel implements KernelContract
      */
     public function terminate($input, $status)
     {
-        //
+        $this->app->terminate();
     }
 
     /**
@@ -208,8 +256,14 @@ class Kernel implements KernelContract
     protected function getArtisan()
     {
         if (is_null($this->artisan)) {
-            return $this->artisan = (new Artisan($this->app, $this->app->make('events'), $this->app->version()))
-                                ->resolveCommands($this->getCommands());
+            $this->artisan = (new Artisan($this->app, $this->app->make('events'), $this->app->version()))
+                                ->resolveCommands($this->getCommands())
+                                ->setContainerCommandLoader();
+
+            if ($this->symfonyDispatcher instanceof EventDispatcher) {
+                $this->artisan->setDispatcher($this->symfonyDispatcher);
+                $this->artisan->setSignalsToDispatchEvent();
+            }
         }
 
         return $this->artisan;
